@@ -119,7 +119,7 @@ generate_rsa_params (void)
 int
 main (void)
 {
-  int err, listen_sd, i;
+  int err, listen_sd;
   int sd, ret;
   struct sockaddr_in sa_serv;
   struct sockaddr_in sa_cli;
@@ -207,7 +207,6 @@ main (void)
 
       /* print_info(session); */
 
-      i = 0;
       for (;;)
 	{
 	  memset (buffer, 0, MAX_BUF + 1);
