@@ -496,7 +496,7 @@ _gnutls_read_connection_state_init (gnutls_session_t session)
   if (rc < 0)
     return rc;
 
-  _gnutls_handshake_log ("HSK[%x]: Cipher Suite: %s\n",
+  _gnutls_handshake_log ("HSK[%p]: Cipher Suite: %s\n",
 			 session,
 			 _gnutls_cipher_suite_get_name
 			 (&session->security_parameters.
@@ -532,7 +532,7 @@ _gnutls_read_connection_state_init (gnutls_session_t session)
 			       read_mac_algorithm);
 
   _gnutls_handshake_log
-    ("HSK[%x]: Initializing internal [read] cipher sessions\n", session);
+    ("HSK[%p]: Initializing internal [read] cipher sessions\n", session);
 
   switch (session->security_parameters.entity)
     {
@@ -677,7 +677,7 @@ _gnutls_write_connection_state_init (gnutls_session_t session)
   if (rc < 0)
     return rc;
 
-  _gnutls_handshake_log ("HSK[%x]: Cipher Suite: %s\n", session,
+  _gnutls_handshake_log ("HSK[%p]: Cipher Suite: %s\n", session,
 			 _gnutls_cipher_suite_get_name
 			 (&session->security_parameters.
 			  current_cipher_suite));
@@ -714,7 +714,7 @@ _gnutls_write_connection_state_init (gnutls_session_t session)
 			       write_mac_algorithm);
 
   _gnutls_handshake_log
-    ("HSK[%x]: Initializing internal [write] cipher sessions\n", session);
+    ("HSK[%p]: Initializing internal [write] cipher sessions\n", session);
 
   switch (session->security_parameters.entity)
     {
