@@ -25,7 +25,6 @@
 # include <config.h>
 #endif
 #include <stdio.h>
-#include <assert.h>
 #include <sys/stat.h>
 
 #include "opencdk.h"
@@ -42,7 +41,7 @@ hash_encode (void *data, FILE * in, FILE * out)
 
   if (!mfx)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return CDK_Inv_Value;
     }
 
@@ -52,10 +51,10 @@ hash_encode (void *data, FILE * in, FILE * out)
     {
       err = _gnutls_hash_init (&mfx->md, mfx->digest_algo);
       if (err < 0)
-        {
-          gnutls_assert();
-  	  return map_gnutls_error (err);
-        }
+	{
+	  gnutls_assert ();
+	  return map_gnutls_error (err);
+	}
 
       mfx->md_initialized = 1;
     }
@@ -88,7 +87,7 @@ _cdk_filter_hash (void *data, int ctl, FILE * in, FILE * out)
 	  return 0;
 	}
     }
-    
-  gnutls_assert();
+
+  gnutls_assert ();
   return CDK_Inv_Mode;
 }
